@@ -21,10 +21,9 @@ for mod in list(sys.modules):
     if mod == 'josepy' or mod.startswith('josepy.'):
         sys.modules['acme.' + mod.replace('josepy', 'jose', 1)] = sys.modules[mod]
 
-
-if sys.version_info[:2] == (3, 5):
+if sys.version_info[0] == 2:
     warnings.warn(
-            "Python 3.5 support will be dropped in the next release of "
-            "acme. Please upgrade your Python version.",
-            PendingDeprecationWarning,
+        "Python 2 support will be dropped in the next release of acme. "
+        "Please upgrade your Python version.",
+        PendingDeprecationWarning,
     )  # pragma: no cover
